{pkgs ? (import "${import ../../nixpkgs-path.nix}" {}), ...}:
{
  imports = [
    (toString ../../common)
    <morph-options> # we include the options here to ensure that we can build with or without morph.
                    # morph-lib must be NIX_PATH and point to the lib path of the morph that is being
		    # used for deployment.  This is done automatically with shell.nix.
  ];
  config = {
    environment.systemPackages = with pkgs; [ bridge-utils git ];
    programs.neovim.enable = true;
    programs.neovim.vimAlias = true;
    programs.neovim.viAlias = true;
    
    networking.domain = "cascade.strudelline.net";
    networking.search = [ "cascade.strudelline.net" "strudelline.net" ];
    networking.nameservers = [ "172.16.44.1" "172.16.1.1" ];
    cascade.bridge-mac-prefix = "00:80:10";

    environment.binbash.enable = true;

    services.getty.autologinUser = pkgs.lib.mkForce "root";

    services.sshd.enable = true;
    networking.firewall.allowedTCPPorts = [ 22 ];

    system.stateVersion = "22.11";


    nix.nixPath = with pkgs; [
      "nixpkgs=${ import ../../nixpkgs-path.nix }"
      "home-manager=/usr/src/home-manager"
      "morph-options=${morph.lib}/options.nix"
    ];
  };
}
